@@ -23,10 +23,15 @@
 #define NODE_VERSION_H
 
 #define NODE_MAJOR_VERSION 0
-#define NODE_MINOR_VERSION 8
-#define NODE_PATCH_VERSION 16
+#define NODE_MINOR_VERSION 10
+#define NODE_PATCH_VERSION 32
+
 #define NODE_VERSION_IS_RELEASE 1
 
+#ifndef NODE_TAG
+# define NODE_TAG ""
+#endif
+
 #ifndef NODE_STRINGIFY
 #define NODE_STRINGIFY(n) NODE_STRINGIFY_HELPER(n)
 #define NODE_STRINGIFY_HELPER(n) #n
@@ -35,11 +40,13 @@
 #if NODE_VERSION_IS_RELEASE
 # define NODE_VERSION_STRING  NODE_STRINGIFY(NODE_MAJOR_VERSION) "." \
                               NODE_STRINGIFY(NODE_MINOR_VERSION) "." \
-                              NODE_STRINGIFY(NODE_PATCH_VERSION)
+                              NODE_STRINGIFY(NODE_PATCH_VERSION)     \
+                              NODE_TAG
 #else
 # define NODE_VERSION_STRING  NODE_STRINGIFY(NODE_MAJOR_VERSION) "." \
                               NODE_STRINGIFY(NODE_MINOR_VERSION) "." \
-                              NODE_STRINGIFY(NODE_PATCH_VERSION) "-pre"
+                              NODE_STRINGIFY(NODE_PATCH_VERSION)     \
+                              NODE_TAG "-pre"
 #endif
 
 #define NODE_VERSION "v" NODE_VERSION_STRING
